"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = fetchPng;
var _pngjs = require("pngjs");
var _nodeFetch = _interopRequireDefault(require("node-fetch"));
var _jose = require("jose");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
async function fetchPng(url, {
  apiKey,
  apiSecret,
  endpoint
}) {
  const headers = {};
  if (url.startsWith(endpoint)) {
    const encodedSecret = new TextEncoder().encode(apiSecret);
    // https://github.com/panva/jose/blob/main/docs/classes/jwt_sign.SignJWT.md
    const signed = await new _jose.SignJWT({
      key: apiKey
    }).setProtectedHeader({
      alg: 'HS256',
      kid: apiKey
    }).sign(encodedSecret);
    headers.Authorization = `Bearer ${signed}`;
  }
  const response = await (0, _nodeFetch.default)(url, {
    headers
  });
  if (!response.ok) {
    throw new Error(`Failed to fetch PNG at ${url}. Response ${response.status}: ${await response.text()}`);
  }
  const contentType = response.headers.get('Content-Type') || 'unknown';
  if (!url.startsWith(endpoint) && !contentType.startsWith('image/png')) {
    throw new Error(`Failed to fetch PNG at ${url}. Response has wrong content type: ${contentType}`);
  }
  return new Promise((resolve, reject) => {
    response.body.pipe(new _pngjs.PNG()).on('parsed', function handleParsed() {
      resolve(this);
    }).on('error', reject);
  });
}